@@ -23,12 +23,12 @@ class MicroBlogPost(BlogPost):
             the content in an rss format
     """
 
-    title = ""
 
     def __init__(self, **kwargs):
         """checks published options and accepts the first that is listed"""
         super().__init__(**kwargs)
         self.slug = pendulum.parse(self.date_published, strict=False).format("YMDHmS")
+        self.title = ""
         self.url = f"{self.routes[0]}/{self.slug}"
 
     @property
