@@ -6,7 +6,7 @@ class Search:
     def __init__(self, name):
         self.name = name
 
-    def build_index(self, pages, keys, filepath="search.json"):
+    def build_index(self, pages, keys, filepath):
         search_index = []
 
         for page in pages:
@@ -21,8 +21,8 @@ class Search:
                 logging.debug(vars(page))
                 search_index.append({x: str(y) for x, y in vars(page).items()})
 
-        with open(filepath, "w") as json_file:
-            return json.dump(search_index, json_file)
+        with open(filepath, 'w') as jsonfile:
+            return json.dump(search_index, fp=jsonfile)
 
 
 Fuse = Search("fuse")
